@@ -25,10 +25,7 @@ var tools = {
     },
 
     getIdentityKey: function (email) {
-        let acctMgr = Components.classes["@mozilla.org/messenger/account-manager;1"].getService(Components.interfaces.nsIMsgAccountManager);
-        let accounts = acctMgr.accounts;
-        for (let a = 0; a < accounts.length; a++) {
-            let account = accounts.queryElementAt(a, Components.interfaces.nsIMsgAccount);
+        for (let account of MailServices.accounts.accounts) {
             if (account.defaultIdentity && account.defaultIdentity.email == email) return account.defaultIdentity.key;
         }
         return "";
@@ -57,8 +54,7 @@ var tools = {
     
     getUriFromDirectoryId: function(ownerId) {
         let directories = MailServices.ab.directories;
-        while (directories.hasMoreElements()) {
-          let directory = directories.getNext();
+        for (let directory of directories) {
           if (directory instanceof Components.interfaces.nsIAbDirectory) {
                 if (ownerId.startsWith(directory.dirPrefId)) return directory.URI;
           }
@@ -87,7 +83,7 @@ var tools = {
                                  null,
                                  Services.scriptSecurityManager.getSystemPrincipal(),
                                  null,
-                                 Components.interfaces.nsILoadInfo.SEC_REQUIRE_SAME_ORIGIN_DATA_INHERITS,
+                                 Components.interfaces.nsILoadInfo.SEC_REQUIRE_SAME_ORIGIN_INHERITS_SEC_CONTEXT,
                                  Components.interfaces.nsIContentPolicy.TYPE_OTHER);
 
             NetUtil.asyncFetch(channel, (inputStream, status) => {
@@ -294,7 +290,7 @@ var tools = {
     //guess the IANA timezone (used by TB) based on the current offset (standard or daylight)
     guessTimezoneByCurrentOffset: function(curOffset, utcDateTime) {
         //if we only now the current offset and the current date, we need to actually try each TZ.
-        let tzService = TbSync.lightning.cal.getTimezoneService();
+        let tzService = TbSync.lightning.cal.timezoneService;
 
         //first try default tz
         let test = utcDateTime.getInTimezone(eas.defaultTimezoneInfo.timezone);
@@ -333,9 +329,9 @@ var tools = {
                 eas.cachedTimezoneData.iana = {};
                 eas.cachedTimezoneData.abbreviations = {};
                 eas.cachedTimezoneData.stdOffset = {};
-                eas.cachedTimezoneData.bothOffsets = {};                    
+                eas.cachedTimezoneData.bothOffsets = {};
                     
-                let tzService = TbSync.lightning.cal.getTimezoneService();
+                let tzService = TbSync.lightning.cal.timezoneService;
 
                 //cache timezones data from internal IANA data
                 let enumerator = tzService.timezoneIds;
@@ -528,12 +524,10 @@ var tools = {
 
 //TODO: Invites
 /*
-if (TbSync.lightningIsAvailable()) {
     cal.itip.checkAndSendOrigial = cal.itip.checkAndSend;
     cal.itip.checkAndSend = function(aOpType, aItem, aOriginalItem) {
         //if this item is added_by_user, do not call checkAndSend yet, because the UID is wrong, we need to sync first to get the correct ID - TODO
         TbSync.dump("cal.checkAndSend", aOpType);
         cal.itip.checkAndSendOrigial(aOpType, aItem, aOriginalItem);
     }
-}
 */
